==> easytag_1.99.3.orig.tar.gz: easytag-1.99.3/src/ui_manager.h <==
/*
 * As of GTK 2.4.1, separators do not need unique names
 * Consider removing the name properties once it is widespread
 */

static const gchar *ui_xml =
"<ui>"

/*
 * Menu bar
 */
"  <menubar name='MenuBar'>"
"    <menu action='FileMenu'>"

"      <menu action='SortTagMenu'>"
"        <menuitem action='SortTrackNumAsc' />"
"        <menuitem action='SortTrackNumDesc' />"
"        <separator name='a1' />"
"        <menuitem action='SortTitleAsc' />"
"        <menuitem action='SortTitleDesc' />"
"        <separator name='a2' />"
"        <menuitem action='SortArtistAsc' />"
"        <menuitem action='SortArtistDesc' />"
"        <separator name='a3' />"
"        <menuitem action='SortAlbumAsc' />"
"        <menuitem action='SortAlbumDesc' />"
"        <separator name='a4' />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator name='a5' />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator name='a6' />"
"        <menuitem action='SortGenreAsc' />"
"        <menuitem action='SortGenreDesc' />"
"        <separator name='a7' />"
"        <menuitem action='SortCommentAsc' />"
"        <menuitem action='SortCommentDesc' />"
"        <separator name='a8' />"
"        <menuitem action='SortComposerAsc' />"
"        <menuitem action='SortComposerDesc' />"
"        <separator name='a9' />"
"        <menuitem action='SortOrigArtistAsc' />"
"        <menuitem action='SortOrigArtistDesc' />"
"        <separator name='a10' />"
"        <menuitem action='SortCopyrightAsc' />"
"        <menuitem action='SortCopyrightDesc' />"
"        <separator name='a11' />"
"        <menuitem action='SortUrlAsc' />"
"        <menuitem action='SortUrlDesc' />"
"        <separator name='a12' />"
"        <menuitem action='SortEncodedByAsc' />"
"        <menuitem action='SortEncodedByDesc' />"
"        <separator name='a13' />"
"      </menu>"

"      <menu action='SortPropMenu'>"
"        <menuitem action='SortFilenameAsc' />"
"        <menuitem action='SortFilenameDesc' />"
"        <separator name='b1' />"
"        <menuitem action='SortDateAsc' />"
"        <menuitem action='SortDateDesc' />"
"        <separator name='b2' />"
"        <menuitem action='SortTypeAsc' />"
"        <menuitem action='SortTypeDesc' />"
"        <separator name='b3' />"
"        <menuitem action='SortSizeAsc' />"
"        <menuitem action='SortSizeDesc' />"
"        <separator name='b4' />"
"        <menuitem action='SortDurationAsc' />"
"        <menuitem action='SortDurationDesc' />"
"        <separator name='b5' />"
"        <menuitem action='SortBitrateAsc' />"
"        <menuitem action='SortBitrateDesc' />"
"        <separator name='b6' />"
"        <menuitem action='SortSamplerateAsc' />"
"        <menuitem action='SortSamplerateDesc' />"
"      </menu>"

"      <menuitem action='Open' />"
"      <separator name='c1' />"

"      <menuitem action='SelAll' />"
"      <menuitem action='UnselAll' />"
"      <menuitem action='SelInv' />"
"      <separator name='d1' />"

"      <menuitem action='DeleteFile' />"
"      <separator name='e1' />"

"      <menuitem action='FirstFile' />"
"      <menuitem action='PreviousFile' />"
"      <menuitem action='NextFile' />"
"      <menuitem action='LastFile' />"
"      <separator name='f1' />"

"      <menuitem action='ScanFile' />"
"      <menuitem action='RemoveTag' />"
"      <menuitem action='UndoFile' />"
"      <menuitem action='RedoFile' />"
"      <menuitem action='SaveFile' />"
"      <separator name='g1' />"

"      <menuitem action='Undo' />"
"      <menuitem action='Redo' />"
"      <separator name='h1' />"

"      <menuitem action='Quit' />"
"    </menu>"


"    <menu action='BrowserMenu'>"
"      <menuitem action='GoToHome' />"
"      <menuitem action='GoToDefaultPath' />"
"      <menuitem action='SetDefaultPath' />"
"      <separator name='i1' />"

"      <menuitem action='ViewMode' />"
"      <menuitem action='RenameDir' />"
"      <menuitem action='ReloadDir' />"
"      <menuitem action='BrowseDir' />"
"      <separator name='j1' />"

"      <menuitem action='BrowseSubdir' />"
"      <separator name='k1' />"

"      <menuitem action='CollapseTree' />"
"      <menuitem action='RefreshTree' />"
"    </menu>"

"    <menu action='ScannerMenu'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"

"    <menu action='MiscMenu'>"
"      <menuitem action='SearchFile' />"
"      <menuitem action='CDDBSearch' />"
"      <separator name='l1' />"

"      <menuitem action='LoadFilenames' />"
"      <menuitem action='WritePlaylist' />"
"      <menuitem action='RunAudio' />"
"    </menu>"

"    <menu action='SettingsMenu'>"
"      <menuitem action='Preferences' />"
"      <separator name='m1' />"
"      <menuitem action='SaveConfig' />"
"    </menu>"

"    <menu action='HelpMenu'>"
"      <menuitem action='About' />"
"    </menu>"

"  </menubar>"


/*
 * Tool bar
 */
"  <toolbar name='ToolBar'>"
"    <toolitem action='FirstFile'/>"
"    <toolitem action='PreviousFile'/>"
"    <toolitem action='NextFile'/>"
"    <toolitem action='LastFile'/>"
"    <separator name='n1'/>"

"    <toolitem action='ScanFile'/>"
"    <toolitem action='RemoveTag'/>"
"    <toolitem action='UndoFile'/>"
"    <toolitem action='RedoFile'/>"
"    <toolitem action='SaveFile'/>"
"    <separator name='o1'/>"

"    <toolitem action='ViewModeToggle'/>"
"    <toolitem action='SelAll'/>"
"    <toolitem action='SelInv'/>"
"    <separator name='p1'/>"

"    <toolitem action='Stop'/>"
"    <separator name='q1'/>"

"    <toolitem action='Quit'/>"
"  </toolbar>"


/*
 * Popup menus
 */
"  <popup name='FilePopup'>"
"    <menuitem action='SelAll' />"
"    <menuitem action='UnselAll' />"
"    <menuitem action='SelInv' />"
"    <separator name='r1'/>"
"    <menuitem action='RunAudio' />"
"    <separator name='r2'/>"
"    <menu action='ScannerSubpopup'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"
"    <menuitem action='SearchFile' />"
"    <menuitem action='DeleteFile' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='Open' />"
"    <separator name='s1'/>"

"    <menu action='SortTagMenu'>"
"      <menuitem action='SortTrackNumAsc' />"
"      <menuitem action='SortTrackNumDesc' />"
"      <separator name='u1' />"
"      <menuitem action='SortTitleAsc' />"
"      <menuitem action='SortTitleDesc' />"
"      <separator name='u2' />"
"      <menuitem action='SortArtistAsc' />"
"      <menuitem action='SortArtistDesc' />"
"      <separator name='u3' />"
"      <menuitem action='SortAlbumAsc' />"
"      <menuitem action='SortAlbumDesc' />"
"      <separator name='u4' />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator name='u5' />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator name='u6' />"
"      <menuitem action='SortGenreAsc' />"
"      <menuitem action='SortGenreDesc' />"
"      <separator name='u7' />"
"      <menuitem action='SortCommentAsc' />"
"      <menuitem action='SortCommentDesc' />"
"      <separator name='u8' />"
"      <menuitem action='SortComposerAsc' />"
"      <menuitem action='SortComposerDesc' />"
"      <separator name='u9' />"
"      <menuitem action='SortOrigArtistAsc' />"
"      <menuitem action='SortOrigArtistDesc' />"
"      <separator name='u10' />"
"      <menuitem action='SortCopyrightAsc' />"
"      <menuitem action='SortCopyrightDesc' />"
"      <separator name='u11' />"
"      <menuitem action='SortUrlAsc' />"
"      <menuitem action='SortUrlDesc' />"
"      <separator name='u12' />"
"      <menuitem action='SortEncodedByAsc' />"
"      <menuitem action='SortEncodedByDesc' />"
"      <separator name='u13' />"
"    </menu>"

"    <menu action='SortPropMenu'>"
"      <menuitem action='SortFilenameAsc' />"
"      <menuitem action='SortFilenameDesc' />"
"      <separator name='v1' />"
"      <menuitem action='SortDateAsc' />"
"      <menuitem action='SortDateDesc' />"
"      <separator name='v2' />"
"      <menuitem action='SortTypeAsc' />"
"      <menuitem action='SortTypeDesc' />"
"      <separator name='v3' />"
"      <menuitem action='SortSizeAsc' />"
"      <menuitem action='SortSizeDesc' />"
"      <separator name='v4' />"
"      <menuitem action='SortDurationAsc' />"
"      <menuitem action='SortDurationDesc' />"
"      <separator name='v5' />"
"      <menuitem action='SortBitrateAsc' />"
"      <menuitem action='SortBitrateDesc' />"
"      <separator name='v6' />"
"      <menuitem action='SortSamplerateAsc' />"
"      <menuitem action='SortSamplerateDesc' />"
"    </menu>"
"  </popup>"

"  <popup name='DirPopup'>"
"    <menuitem action='DirPopupRunAudio' />"
"    <separator name='w1'/>"
"    <menuitem action='GoToHome' />"
"    <menuitem action='GoToDefaultPath' />"
"    <menuitem action='SetDefaultPath' />"
"    <separator name='w2'/>"
"    <menuitem action='RenameDir' />"
"    <menuitem action='ReloadDir' />"
"    <menuitem action='BrowseDir' />"
"    <separator name='w3'/>"
"    <menuitem action='BrowseSubdir' />"
"    <separator name='w4'/>"
"    <menuitem action='CollapseTree' />"
"    <menuitem action='RefreshTree' />"
"  </popup>"

"</ui>";

==> easytag_1.99.10.orig.tar.gz: easytag-1.99.10/src/ui_manager.h <==
/*
 * As of GTK 2.4.1, separators do not need unique names
 * Consider removing the name properties once it is widespread
 *
 * - bar.h : defines constant associated to the action "<menuitem action="
 * - bar.c : Create_UI() does the actions
 */

static const gchar *ui_xml =
"<ui>"

/*
 * Menu bar
 */
"  <menubar name='MenuBar'>"
"    <menu action='FileMenu'>"

"      <menu action='SortTagMenu'>"
"        <menuitem action='SortTrackNumAsc' />"
"        <menuitem action='SortTrackNumDesc' />"
"        <separator name='a1' />"
"        <menuitem action='SortTitleAsc' />"
"        <menuitem action='SortTitleDesc' />"
"        <separator name='a2' />"
"        <menuitem action='SortArtistAsc' />"
"        <menuitem action='SortArtistDesc' />"
"        <separator name='a3' />"
"        <menuitem action='SortAlbumAsc' />"
"        <menuitem action='SortAlbumDesc' />"
"        <separator name='a4' />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator name='a5' />"
"        <menuitem action='SortYearAsc' />"
"        <menuitem action='SortYearDesc' />"
"        <separator name='a6' />"
"        <menuitem action='SortGenreAsc' />"
"        <menuitem action='SortGenreDesc' />"
"        <separator name='a7' />"
"        <menuitem action='SortCommentAsc' />"
"        <menuitem action='SortCommentDesc' />"
"        <separator name='a8' />"
"        <menuitem action='SortComposerAsc' />"
"        <menuitem action='SortComposerDesc' />"
"        <separator name='a9' />"
"        <menuitem action='SortOrigArtistAsc' />"
"        <menuitem action='SortOrigArtistDesc' />"
"        <separator name='a10' />"
"        <menuitem action='SortCopyrightAsc' />"
"        <menuitem action='SortCopyrightDesc' />"
"        <separator name='a11' />"
"        <menuitem action='SortUrlAsc' />"
"        <menuitem action='SortUrlDesc' />"
"        <separator name='a12' />"
"        <menuitem action='SortEncodedByAsc' />"
"        <menuitem action='SortEncodedByDesc' />"
"        <separator name='a13' />"
"      </menu>"

"      <menu action='SortPropMenu'>"
"        <menuitem action='SortFilenameAsc' />"
"        <menuitem action='SortFilenameDesc' />"
"        <separator name='b1' />"
"        <menuitem action='SortDateAsc' />"
"        <menuitem action='SortDateDesc' />"
"        <separator name='b2' />"
"        <menuitem action='SortTypeAsc' />"
"        <menuitem action='SortTypeDesc' />"
"        <separator name='b3' />"
"        <menuitem action='SortSizeAsc' />"
"        <menuitem action='SortSizeDesc' />"
"        <separator name='b4' />"
"        <menuitem action='SortDurationAsc' />"
"        <menuitem action='SortDurationDesc' />"
"        <separator name='b5' />"
"        <menuitem action='SortBitrateAsc' />"
"        <menuitem action='SortBitrateDesc' />"
"        <separator name='b6' />"
"        <menuitem action='SortSamplerateAsc' />"
"        <menuitem action='SortSamplerateDesc' />"
"      </menu>"

#ifndef WIN32
"      <menuitem action='Open' />"
#endif
"      <separator name='c1' />"

"      <menuitem action='SelAll' />"
"      <menuitem action='UnselAll' />"
"      <menuitem action='SelInv' />"
"      <separator name='d1' />"

"      <menuitem action='DeleteFile' />"
"      <separator name='e1' />"

"      <menuitem action='FirstFile' />"
"      <menuitem action='PreviousFile' />"
"      <menuitem action='NextFile' />"
"      <menuitem action='LastFile' />"
"      <separator name='f1' />"

"      <menuitem action='ScanFile' />"
"      <menuitem action='RemoveTag' />"
"      <menuitem action='UndoFile' />"
"      <menuitem action='RedoFile' />"
"      <menuitem action='SaveFile' />"
"      <separator name='g1' />"

"      <menuitem action='Undo' />"
"      <menuitem action='Redo' />"
"      <separator name='h1' />"

"      <menuitem action='Quit' />"
"    </menu>"


"    <menu action='BrowserMenu'>"
"      <menuitem action='GoToHome' />"
"      <menuitem action='GoToDefaultPath' />"
"      <menuitem action='SetDefaultPath' />"
"      <separator name='i1' />"

"      <menuitem action='ViewMode' />"
"      <menuitem action='RenameDir' />"
"      <menuitem action='ReloadDir' />"
#ifndef WIN32
"      <menuitem action='BrowseDir' />"
#endif
"      <separator name='j1' />"

"      <menuitem action='BrowseSubdir' />"
#ifndef WIN32
"      <menuitem action='BrowseHiddenDir' />"
#endif
"      <separator name='k1' />"

"      <menuitem action='CollapseTree' />"
"      <menuitem action='RefreshTree' />"
"    </menu>"

"    <menu action='ScannerMenu'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"

"    <menu action='MiscMenu'>"
"      <menuitem action='SearchFile' />"
"      <menuitem action='CDDBSearch' />"
"      <separator name='l1' />"

"      <menuitem action='LoadFilenames' />"
"      <menuitem action='WritePlaylist' />"
"      <menuitem action='RunAudio' />"
"    </menu>"

"    <menu action='SettingsMenu'>"
"      <menuitem action='Preferences' />"
"    </menu>"

"    <menu action='HelpMenu'>"
"      <menuitem action='About' />"
"    </menu>"

"  </menubar>"


/*
 * Tool bar
 */
"  <toolbar name='ToolBar'>"
"    <toolitem action='FirstFile'/>"
"    <toolitem action='PreviousFile'/>"
"    <toolitem action='NextFile'/>"
"    <toolitem action='LastFile'/>"
"    <separator name='n1'/>"

"    <toolitem action='ScanFile'/>"
"    <toolitem action='RemoveTag'/>"
"    <toolitem action='UndoFile'/>"
"    <toolitem action='RedoFile'/>"
"    <toolitem action='SaveFile'/>"
"    <separator name='o1'/>"

"    <toolitem action='ViewModeToggle'/>"
"    <toolitem action='SelAll'/>"
"    <toolitem action='SelInv'/>"
"    <separator name='p1'/>"

"    <toolitem action='Stop'/>"
"    <separator name='q1'/>"

"    <toolitem action='Quit'/>"
"  </toolbar>"


/*
 * Popup menus
 */
"  <popup name='FilePopup'>"
"    <menuitem action='SelAll' />"
"    <menuitem action='UnselAll' />"
"    <menuitem action='SelInv' />"
"    <separator name='r1'/>"
"    <menuitem action='RunAudio' />"
"    <separator name='r2'/>"
"    <menu action='ScannerSubpopup'>"
"      <menuitem action='FillTag' />"
"      <menuitem action='RenameFile' />"
"      <menuitem action='ProcessFields' />"
"    </menu>"
"    <menuitem action='CDDBSearchFile' />"
"    <menuitem action='SearchFile' />"
"    <menuitem action='DeleteFile' />"
"    <menuitem action='ReloadDir' />"
#ifndef WIN32
"    <menuitem action='Open' />"
#endif
"    <separator name='s1'/>"

"    <menu action='SortTagMenu'>"
"      <menuitem action='SortTrackNumAsc' />"
"      <menuitem action='SortTrackNumDesc' />"
"      <separator name='u1' />"
"      <menuitem action='SortTitleAsc' />"
"      <menuitem action='SortTitleDesc' />"
"      <separator name='u2' />"
"      <menuitem action='SortArtistAsc' />"
"      <menuitem action='SortArtistDesc' />"
"      <separator name='u3' />"
"      <menuitem action='SortAlbumAsc' />"
"      <menuitem action='SortAlbumDesc' />"
"      <separator name='u4' />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator name='u5' />"
"      <menuitem action='SortYearAsc' />"
"      <menuitem action='SortYearDesc' />"
"      <separator name='u6' />"
"      <menuitem action='SortGenreAsc' />"
"      <menuitem action='SortGenreDesc' />"
"      <separator name='u7' />"
"      <menuitem action='SortCommentAsc' />"
"      <menuitem action='SortCommentDesc' />"
"      <separator name='u8' />"
"      <menuitem action='SortComposerAsc' />"
"      <menuitem action='SortComposerDesc' />"
"      <separator name='u9' />"
"      <menuitem action='SortOrigArtistAsc' />"
"      <menuitem action='SortOrigArtistDesc' />"
"      <separator name='u10' />"
"      <menuitem action='SortCopyrightAsc' />"
"      <menuitem action='SortCopyrightDesc' />"
"      <separator name='u11' />"
"      <menuitem action='SortUrlAsc' />"
"      <menuitem action='SortUrlDesc' />"
"      <separator name='u12' />"
"      <menuitem action='SortEncodedByAsc' />"
"      <menuitem action='SortEncodedByDesc' />"
"      <separator name='u13' />"
"    </menu>"

"    <menu action='SortPropMenu'>"
"      <menuitem action='SortFilenameAsc' />"
"      <menuitem action='SortFilenameDesc' />"
"      <separator name='v1' />"
"      <menuitem action='SortDateAsc' />"
"      <menuitem action='SortDateDesc' />"
"      <separator name='v2' />"
"      <menuitem action='SortTypeAsc' />"
"      <menuitem action='SortTypeDesc' />"
"      <separator name='v3' />"
"      <menuitem action='SortSizeAsc' />"
"      <menuitem action='SortSizeDesc' />"
"      <separator name='v4' />"
"      <menuitem action='SortDurationAsc' />"
"      <menuitem action='SortDurationDesc' />"
"      <separator name='v5' />"
"      <menuitem action='SortBitrateAsc' />"
"      <menuitem action='SortBitrateDesc' />"
"      <separator name='v6' />"
"      <menuitem action='SortSamplerateAsc' />"
"      <menuitem action='SortSamplerateDesc' />"
"    </menu>"
"  </popup>"

"  <popup name='DirPopup'>"
"    <menuitem action='DirPopupRunAudio' />"
"    <separator name='w1'/>"
"    <menuitem action='GoToHome' />"
"    <menuitem action='GoToDefaultPath' />"
"    <menuitem action='SetDefaultPath' />"
"    <separator name='w2'/>"
"    <menuitem action='RenameDir' />"
"    <menuitem action='ReloadDir' />"
#ifndef WIN32
"    <menuitem action='BrowseDir' />"
#endif
"    <separator name='w3'/>"
"    <menuitem action='BrowseSubdir' />"
#ifndef WIN32
"    <menuitem action='BrowseHiddenDir' />"
#endif
"    <separator name='w4'/>"
"    <menuitem action='CollapseTree' />"
"    <menuitem action='RefreshTree' />"
"  </popup>"

"</ui>";
